@@ -2,7 +2,7 @@
 Main module for running the CLI abstraction to the API backend
 
 classes:
-    Main - Represents a CLI
+    Main - Represents a CLI interface
 
 Functions:
     init - Initialises a new CLI instance
@@ -17,6 +17,7 @@ from typing import Collection, Union
 from . import api
 from .utils import Utils, Color
 from .type import StatusDict, Plugin, Metadata, Update
+from .settings import VERSION
 
 
 class Main:
@@ -106,26 +107,27 @@ class Main:
                 continue
 
             plugin: Union[Plugin, None] = self.api.get_plugin_info_if_update(metadata)
+            if plugin is None:
+                continue
 
-            result: StatusDict = {"status": False, "message": ""}
-            if plugin:
-                if self.args.noninteractive:
-                    result = self.api.download_plugin(plugin)
-                else:
-                    update: Update = self.api.get_latest_update_info(plugin)
-                    changelog = update["description"]
-                    Utils.separator()
-                    Utils.format_text(f"Changelog for {plugin['name']}:", Color.STATUS)
-                    Utils.format_text(changelog, Color.STATUS)
-                    Utils.separator()
+            result = {}
 
-                    if Utils.prompt_bool(f"Would you like to update {plugin['name']}?"):
-                        result = self.api.download_plugin(plugin)
-                    else:
-                        result = {
-                            "status": False,
-                            "message": f"Not updating {plugin['name']}",
-                        }
+            if not self.args.noninteractive:
+                update: Update = self.api.get_latest_update_info(plugin)
+                changelog = update["description"]
+                Utils.separator()
+                Utils.format_text(f"Changelog for {plugin['name']}:", Color.STATUS)
+                Utils.format_text(changelog, Color.STATUS)
+                Utils.separator()
+
+                if not Utils.prompt_bool(f"Would you like to update {plugin['name']}?"):
+                    result = {
+                        "status": False,
+                        "message": f"Not updating {plugin['name']}",
+                    }
+
+            if not result:
+                result = self.api.download_plugin(plugin, filename)
 
             color = Color.WARNING
             if result["status"]:
@@ -148,7 +150,8 @@ class Main:
         """
         parser = ArgumentParser(
             description="Spud: The plugin manager for your Spigot Minecraft server",
-            epilog="Licensed under GPLv3 (https://www.gnu.org/licenses/gpl-3.0.en.html)",
+            epilog="Licensed under GPLv3 (https://www.gnu.org/licenses/gpl-3.0.en.html). "
+            "Source available at https://github.com/exciteabletom/spud",
         )
         parser.add_argument("action", help="install or update", type=str)
         parser.add_argument(
@@ -173,6 +176,9 @@ class Main:
             type=Path,
             default=".",
         )
+        parser.add_argument(
+            "-v", "--version", action="version", version=f"%(prog)s {VERSION}"
+        )
         return parser.parse_args()
 
     @staticmethod
